#!/bin/sh
SUD_INSTALL_DIR=/opt/sentinel/sud
sntl_product_info=/var/opt/sentinel/sntl_product.info
MAJOR=6
MINOR=4
REV=0
version=6.4.0
SUD_VER=710
sud_version=7.1.0
SUD_RPM=sntl-sud

#
# This script installs both parallel driver & usb daemon.
#


###############################################################################
                        # Show SSP Banner
###############################################################################
showbanner()
{
echo "-------------------------------------------------------------------------------"
echo "                Sentinel Unix Driver $sud_version Installation Script"
echo "                         Copyright (C) 2005 SafeNet, Inc."
echo "                             All rights reserved."
echo "-------------------------------------------------------------------------------"
}


uninstall_sud()
{
	OLD_SUD_RET=0
	[ -f $sntl_product_info ]
	if [ $? -eq 0 ]
	then
		OLD_SUD_VER=`grep sud $sntl_product_info|cut -d = -f 2|cut -d : -f 2`
		OLD_SUD_PATH=`grep sud $sntl_product_info|cut -d = -f 2|cut -d : -f 3`
		OLD_SUD_RPM=`grep sud $sntl_product_info|cut -d = -f 2|cut -d : -f 1`
		if [ -z $OLD_SUD_VER ]
		then
			OLD_SUD_RET=0
	    else
			if [ $OLD_SUD_VER -eq $SUD_VER ]
			then
				OLD_SUD_RET=1  # Same SUD version
			elif [ $OLD_SUD_VER -lt $SUD_VER ]
			then
				# SUD lower version already installed
				# Upgrade SUD
				OLD_SUD_RET=2 			
				rpm -q $OLD_SUD_RPM > /dev/null 2>&1
				if [ $? -eq 0 ]
				then
					rpm -e  --nodeps $OLD_SUD_RPM > /dev/null 2>&1
					if [ $? -eq 255 ] # ckeck more exit status codes
					then
						echo "WARNING:To Install this software make sure you have Super user (root) permission."
					fi
				fi
			else
				#Higher SUD version already installed. Do Nothing & exit
				OLD_SUD_RET=3
			fi
		fi
	fi
}

uninstall_parallel() 
{	
	# either No SUD exists or SUD older than 700 exists
	OLD_SUD_RET=0
	rpm -q SUD-ParallelDriver-5.50 > /dev/null 2>&1
	if [ $? -eq 0 ]
	then
		# SUD 5.50 found(ssp630)
		OLD_PROD_RET=4		
		rpm -e SUD-ParallelDriver-5.50 > /dev/null 2>&1
		if [ $? -eq 255 ] # ckeck more exit status codes
		then
			echo "WARNING:To Install this software make sure you have Super user (root) permission."
		fi
	fi
	
	# check for ssp700 SUD 700
	rpm -q SUD-ParallelDriver-RH9-7.0.0 > /dev/null 2>&1
	if [ $? -eq 0 ]
	then
		# ssp700 SUD found
		OLD_PROD_RET=6
		rpm -e SUD-ParallelDriver-RH9-7.0.0 > /dev/null 2>&1
		if [ $? -eq 255 ] # ckeck more exit status codes
		then
			echo "WARNING:To Install this software make sure you have Super user (root) permission."
		fi
	fi
}

uninstall_usb()
{    
	# either No SUD exists or SUD older than 700 exists
	OLD_SUD_RET=0
	rpm -q SUD-USBDaemon-5.50 > /dev/null 2>&1
	if [ $? -eq 0 ]
	then
		# SUD 5.50 found(ssp630)
		OLD_PROD_RET=4		
		rpm -e SUD-USBDaemon-5.50 > /dev/null 2>&1
		if [ $? -eq 255 ] # ckeck more exit status codes
		then
			echo "WARNING:To Install this software make sure you have Super user (root) permission."
		fi
	fi
	
	# check for ssp700 SUD 700
	rpm -q SUD-USBDaemon-RH9-7.0.0 > /dev/null 2>&1
	if [ $? -eq 0 ]
	then
		# ssp700 SUD found
		OLD_PROD_RET=6
		rpm -e SUD-USBDaemon-RH9-7.0.0 > /dev/null 2>&1
		if [ $? -eq 255 ] # ckeck more exit status codes
		then
			echo "WARNING:To Install this software make sure you have Super user (root) permission."
		fi
	fi	
}

showlicense()
{
if [ $LicenseSHOW == 0 ]    
then
    #LicAgrmntFound indicates whether LicenseAgreement.txt file present or not
    # value 0 (zero) indicates, its not present, 1 (one) indicates its present.
    #Initially we assume LicenseAgreement.txt is not present.
    LicAgrmntFound=0

    echo $line
    [ -f $LicensePATH1/licenseagreement.txt ] 
    if [ $? == 0 ] 
    then
        LicAgrmntFound=1
        LicensePATH=$LicensePATH1
    fi

    [ -f $LicensePATH2/licenseagreement.txt ]
    if [ $? == 0 ]
    then
        LicAgrmntFound=1
        LicensePATH=$LicensePATH2
    fi

    if [ $LicAgrmntFound == 1 ]
    then
	more $LicensePATH/licenseagreement.txt
	while [ 1 ]
	do 
	  echo -n "Do you Agree with the License(y/n): "
	  read choice
	  case $choice in 
	    'y') 
		break 2
		;;
	    'Y') 
		break 2
		;;
	    'n') 
		exit
		;;
	    'N') 
		exit
		;;
	    *)  
	    	echo "-------------------------------------------------------------------------------"
		;;
	  esac	  
	done
    else
	echo "\"licenseagreement.txt\" file missing."
	echo $line
	exit
    fi
fi
}


#############################################################################
# 			Start Here
##############################################################################

OS="none"
if [ -f /etc/SuSE-release ]
then
	OS="SuSE"
fi

LicensePATH1=.
LicensePATH2=..
LicenseSHOW=${#LicenseSHOW}
showlicense
if [ "$1" != "nobanner" ] ; then
	showbanner
fi

uninstall_sud
if [ $OLD_SUD_RET -eq 1 ]   # Same version exists
then
	echo "Installer has detected Sentinel Unix Driver $sud_version on your system"
	echo "Skipping Sentinel Unix Driver $sud_version installation..."
elif [ $OLD_SUD_RET -eq 3 ] # Higher SUD version exists
then
	echo "Installer has detected a higher version of Sentinel Unix Driver on your system" 
	echo "Skipping Sentinel Unix Driver $sud_version Installation..."
else        # In any other case install the Parallel Driver
	uninstall_parallel
	uninstall_usb
	echo "Installing Sentinel Unix Driver $sud_version"
    	if [ $OS == "SuSE" ]
    	then 
	rpm -Uvh --force $SUD_RPM-$sud_version-0.i386.rpm >/dev/null 2>&1	
	else
	rpm -Uvh --force $SUD_RPM-$sud_version-0.i386.rpm 
	fi
	if [ $? -ne 0 ]; then 
		echo "Installation Failed."
		exit
	fi	
fi

echo "-------------------------------------------------------------------------------"


	
